Acknowledgements
================

Many thanks to following people for the time spent on brainstorming on Asphalt's design:

* Alice Bevan-McGregor
* Antti Haapala
* Darin Gordon
* Guillaume "Cman" Brun

Also thanks to Olli Paloheimo who designed the Asphalt logo.
